[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![PyPI version](https://badge.fury.io/py/smetana.svg)](https://badge.fury.io/py/smetana)
[![Documentation Status](http://readthedocs.org/projects/smetana/badge/?version=latest)](http://smetana.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/cdanielmachado/smetana.svg?branch=master)](https://travis-ci.org/cdanielmachado/smetana)

![SMETANA](logo_300px.png)


Species METabolic interaction ANAlysis (**SMETANA**) is a python-based command line tool to analyse microbial communities. 

It takes as input a microbial communtity (from a collection of genome-scale metabolic models in SBML format) and computes of several metrics that describe the potential for cross-feeding interactions between community members. 

### Documentation

For more details please check: http://smetana.readthedocs.io/
 
### Installation

Can be easily installed using **pip**:

```
pip install smetana
```

### Citing SMETANA:

The algorithms here implemented have been previously described in: [Zelezniak et al, PNAS (2015)](http://www.pnas.org/content/112/20/6449.short).
